function viablePoints = getViablePoints(trajectories, inSafeSetFunc)
% Determines which trajectories exclusively lie within a safe region.
%
%   viablePoints = getViablePoints(trajectories, inSafeSetFunc)
%
% Input parameters:
%
%   trajectories    n x m x p matrix, where n is the number of time steps each
%                   trajectory is calculated for, m is the number of dimensions,
%                   and p is the number of points. The trajectories for p
%                   points over n time steps.
%   
%   inSafeSetFunc   a function that takes in an n x m matrix. Returns TRUE if
%                   all n points consisted of m states fall within the safe
%                   region. 
%                   
% Output parameters:
%
%   viablePoints    n x 1 matrix of boolean values, where n is the number of
%                   points from viablePoints. True for any point that
%                   has its trajectory entirely within the safe region defined
%                   by inSafeSetFunc.
numInitialPoints = size(trajectories, 3);  
viablePoints = false(numInitialPoints,1);
for p = 1:numInitialPoints
    isTrajectoryInSafeSet = inSafeSetFunc(trajectories(:,:,p));
    if all(isTrajectoryInSafeSet)
        viablePoints(p) = true;
    end % if
end % for 
end % function 

